<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID foi alterado",
"Invalid request" => "Pedido Inválido",
"This is an OpenID server endpoint. For more information, see " => "Isto é um endpoint de um servidor OpenID. Para mais informações, veja em",
"Identity: <b>" => "Identidade: <b>",
"Realm: <b>" => "Reino:",
"User: <b>" => "Utilizador: <b>",
"Login" => "Login",
"Error: <b>No user Selected" => "Erro: <b>Não foi seleccionado nenhum Utilizador",
"OpenID" => "OpenID",
"you can authenticate to other sites with this address" => "pode autenticar-se noutros sites com este endereço",
"Authorized OpenID provider" => "Fornecedor OpenID Autorizado",
"Your address at Wordpress, Identi.ca, &hellip;" => "O seu endereço em Wordpress, Identi.ca, &hellip;"
);
